<?php
namespace Modules\Cotacao\Modules\AnaliseCotacoes\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;
//use Modules\Cotacao\Modules\AnaliseCotacoes\Services\Sup06000MapaCotacaoService;
use Util\SupUtilities;

class Sup06000MapaCotacaoController extends \Zeedhi\Framework\Controller\Report
{
    protected $birtStrategy;
    protected $supUtilities;

    public function __construct(ReportService $reportService, $birtStrategy, SupUtilities $supUtilities, $environment)
    {
        parent::__construct($reportService);
        $this->birtStrategy = $birtStrategy;
        $this->supUtilities = $supUtilities;
        $this->environment  = $environment;
    }
    
    protected $reportMapping = array (
        'SUP06000' =>
            array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                "CDFILIAL"       =>     "P_CDFILIAL",
                "DTINICIAL"      =>     "P_DTINICIAL",
                "DTFINAL"        =>     "P_DTFINAL",
                "CDARVPRODINI"   =>     "P_CDPRODINI",
                "CDARVPRODFIM"   =>     "P_CDPRODFIM",
                "CDREGIAO"       =>     "P_CDREGIAO",
                "TCDREGIAO"      =>     "P_TCDREGIAO",
                "CDFORNECED"     =>     "P_CDFORNECED",
                "TCDFORNECED"    =>     "P_TCDFORNECED",
                "CDOPERADOR"     =>     "P_CDOPERADOR",
                "CHBDESCONTO"    =>     "P_CHBDESCONTO",
                "EXIBEQTDE"      =>     "P_EXIBEQTDE",
                "EXIBECOTACAO"   =>     "P_EXIBECOTACAO",
                "EXIBEIPI"       =>     "P_EXIBEIPI",
                "EXIBEPGTO"      =>     "P_EXIBEPGTO",
                "EXIBEREFE"      =>     "P_EXIBEREFE",
                // "NRTIPOCUSTO"    =>     "P_NRTIPOCUSTO",
                // "VRPERCENTACRES" =>     "P_VRPERCENTACRES",
                "EXIBEMENORPREC" =>     "P_EXIBEMENORPREC",
                "EXIBESINT"      =>     "P_EXIBESINT",
                "EXIBEDADOSEM"   =>     "P_EXIBEDADOSEM",
                "COMPARAPRODESTOQUE" => "P_COMPARAPRODESTOQUE",
                "MELHORPRECOEMBALAGEM" => "P_MELHORPRECOEMBALAGEM",
                "NRORG"          =>     "P_NRORG"
            )
        )
    );
        
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $nullParams = array();
        
        $row = $request->getRow();
        
        $row['__report_name']  = $row['REPORT_NAME'];
        $row['EXIBEREFE']      = 'A';
        $row['EXIBEPGTO']      = 'S';
        $row['EXIBEIPI']       = 'S';
        
        if ($row['CDREGIAO'] === 'T') {
            $row['CDREGIAO'] = null;
            $row['TCDREGIAO'] = 'T';
        } else {
            $row['TCDREGIAO'] = null;
        }
        
        if ($row['CDFORNECED'] === 'T') {
            $row['CDFORNECED'] = null;
            $row['TCDFORNECED'] = 'T';
        } else {
            $row['TCDFORNECED'] = null;
        }
        
        $filialLogada = $this->environment->getCdFilial();
        
        $row['CDFILIAL'] = $this->supUtilities->getCentralCompras($filialLogada)['CDFILCENTCMP'];
        $row['NRORG'] = $this->environment->getNrOrg();
        
        $this->birtStrategy->setReportFormat($row['REPORT_EXTENSION']);
        $this->birtStrategy->setViewMode('preview');
    }
    
    public function getReportParams(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
    }
}
