/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: CUSTO_DO_PRODUTO.SQL                                              
                                                                            
Descrio:                                                                 
Retorna o custo de um Produto em uma determinada data.                     
                                                                            
P_CDFILIAL     - Cdigo da Filial.                                         
P_CDPRODUTO    - Cdigo do Produto.                                        
P_NRTIPOCUST   - Nmero do Tipo de Custo (1 a 10)                          
P_DTREFERENCIA - Data do Custo.                                            
                                                                            
TIPOS DE CUSTO:                                                            
                                                                            
01 - ltimo custo de compra                                                
02 - Ultimo custo atualizado                                               
03 - ltimo custo (em moeda forte)
04 - Ultimo custo de cotao (AF)                                          
05 - Custo mdio (lquido) atual                                           
06 - Custo mdio (lquido) da poca                                        
07 - Custo mdio (lquido em moeda forte)                                  
08 - Custo mdio (bruto) atual                                             
09 - Custo mdio (bruto) da poca                                          
10 - Custo mdio (bruto em moeda forte)                                    

Criao:                                                                   
12/08/98 - Ederson                                                         

Manutenes:                                                               
__/__/98 - _______ - ___________                                           

*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE 
	        O.NAME = 'CUSTO_DO_PRODUTO_PLA'  AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID             		        AND
	        U.NAME = USER)

  DROP PROCEDURE CUSTO_DO_PRODUTO_PLA
  GO

CREATE PROCEDURE CUSTO_DO_PRODUTO_PLA @P_CDFILIAL     VARCHAR(4),
                                      @P_CDPRODUTO    VARCHAR(10),
                                      @P_NRTIPOCUST   NUMERIC,
                                      @P_DTREFERENCIA DATETIME,
                                      @P_CUSTO NUMERIC(15,6) OUTPUT

AS

   DECLARE @V_CUSTO NUMERIC(15,6);

   DECLARE @V_VRULTICUST NUMERIC(15,6);
   DECLARE @V_VRULTICOTA NUMERIC(15,6);
   DECLARE @V_VRCUSTMEDI NUMERIC(15,6);

BEGIN

   EXEC VERIFICA_CUSTO @P_CDFILIAL,
                       @P_CDPRODUTO,
                       @P_NRTIPOCUST,
                       @P_DTREFERENCIA,
                       @P_VRULTICUST = @V_VRULTICUST OUTPUT,
                       @P_VRULTICOTA = @V_VRULTICOTA OUTPUT,
                       @P_VRCUSTMEDI = @V_VRCUSTMEDI OUTPUT;

   SET @V_CUSTO = 0;

   IF @P_NRTIPOCUST IN (1, 2, 3)
   BEGIN
      SET @V_CUSTO = @V_VRULTICUST;
   END;

   IF @P_NRTIPOCUST IN (4,11)
   BEGIN
      SET @V_CUSTO = @V_VRULTICOTA;
   END;

   IF @P_NRTIPOCUST IN (5, 6, 7, 8, 9, 10)
   BEGIN
      SET @V_CUSTO = @V_VRCUSTMEDI;
   END;

   SET @P_CUSTO = ROUND(@V_CUSTO,5);

END;
GO

