/**
 * 	Used to decorate containers, that is, change their behaviour based on domain specific conditions
 *
 *	@class
 *	@name ContainerDecoratorProvider
 *	@param ContainerDecoratorPreference (description)
 */
function ContainerDecoratorProvider(ContainerDecoratorPreference) {
	var providers = [ContainerDecoratorPreference];

	this.provide = function (containerName, container) {
		return providers;
	};

	/**
	 * Register a new decorator
	 * @function registerProvider
	 * @memberof ContainerDecoratorProvider
	 * @instance
	 * @param {Decorator} decorator - Instance of a decorator to be registered
	 * @returns {Number} Index of the registered decorator.
	 */
	this.registerProvider = function (decorator) {
		providers.push(decorator);
	};

	/**
	 * Deregisters a decorator
	 * @function deregisterProvider
	 * @memberof ContainerDecoratorProvider
	 * @instance
	 * @param {Decorator} decorator - Instance of a decorator to be unregistered
	 */
	this.deregisterProvider = function deregisterProvider(decorator) {
		var index = providers.indexOf(decorator);
		providers.splice(index, 1);
	};
	
	this.unregisterProvider = this.deregisterProvider;
}